@@ -1,6 +1,6 @@
-import unittest
-import subprocess
 import glob
+import subprocess
+import unittest
 
 
 class TestCodingstyle(unittest.TestCase):
@@ -11,12 +11,11 @@ class TestCodingstyle(unittest.TestCase):
                        + pyfiles, check=True)
         subprocess.run(["pyflakes"] + pyfiles, check=True)
         subprocess.run(["pylint", "--disable=missing-docstring,invalid-name,"
-                                  "bad-continuation,consider-using-with,"
-                                  "too-many-lines,consider-using-f-string"]
+                                  "consider-using-with,too-many-lines"]
                        + pyfiles, check=True)
         subprocess.run(["flake8", "--select=DUO"] + pyfiles, check=True)
         subprocess.run(["pyupgrade", "--py311-plus"] + pyfiles, check=True)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
