@@ -1,5 +1,5 @@
-import unittest
 import re
+import unittest
 
 
 class TestCodingstyle(unittest.TestCase):
@@ -20,5 +20,5 @@ class TestCodingstyle(unittest.TestCase):
         self.assertEqual(funcs, docs)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
